@@ -117,6 +117,9 @@ public class XmlVmBaseReader {
                 case "large_icon":
                 object.largeIcon(XmlIconReader.readOne(reader));
                 break;
+                case "lease":
+                object.lease(XmlStorageDomainLeaseReader.readOne(reader));
+                break;
                 case "memory":
                 object.memory(reader.readInteger());
                 break;
